summaryrefslogtreecommitdiffstats
path: root/macosx/tkMacOSXButton.c
diff options
context:
space:
mode:
authorfvogel <fvogelnew1@free.fr>2015-01-02 15:23:43 (GMT)
committerfvogel <fvogelnew1@free.fr>2015-01-02 15:23:43 (GMT)
commitc220a61baa711e24f35d89c3885f5bc2506075e6 (patch)
tree7109ddabeb69b3460db877655087bb8092dd43f6 /macosx/tkMacOSXButton.c
parentf03796c524c990cc4a3a53d5216ebd09fb41e6f2 (diff)
parentaabb1827b3ff53a4b058b0406a581abadcac5bfd (diff)
downloadtk-c220a61baa711e24f35d89c3885f5bc2506075e6.zip
tk-c220a61baa711e24f35d89c3885f5bc2506075e6.tar.gz
tk-c220a61baa711e24f35d89c3885f5bc2506075e6.tar.bz2
Merged core-8-5-branch to text-elided branch
Diffstat (limited to 'macosx/tkMacOSXButton.c')
-rw-r--r--macosx/tkMacOSXButton.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/macosx/tkMacOSXButton.c b/macosx/tkMacOSXButton.c
index b9ee7a3..a84ac97 100644
--- a/macosx/tkMacOSXButton.c
+++ b/macosx/tkMacOSXButton.c
@@ -38,7 +38,7 @@ static NSRect TkMacOSXGetButtonFrame(TkButton *butPtr);
*/
@interface TkNSButton: NSButton
-
+- (void)drawRect:(NSRect)dirtyRect;
@end
@implementation TkNSButton
@@ -67,11 +67,11 @@ static NSRect TkMacOSXGetButtonFrame(TkButton *butPtr);
return;
}
/* Do not draw if the widget is completely outside of its parent, or within 50 pixels of the right border; this prevents buttons from being drawn on peer widgets as scrolling occurs. */
int parent_width = Tk_Width(Tk_Parent(tkwin));
int widget_width = Tk_Width(tkwin);
int x = Tk_X(tkwin);
- if (x > parent_width - 50 || x < 0) {
+ if (x > parent_width - 20 || x < 0) {
return;
}
@@ -67,11 +67,11 @@ static NSRect TkMacOSXGetButtonFrame(TkButton *butPtr);
return;
}
- /* Do not draw if the widget is completely outside of its parent, or within 50 pixels of the right border; this prevents buttons from being drawn on peer widgets as scrolling occurs. */
+ /* Do not draw if the widget is completely outside of its parent, or within 20 pixels of the right border; this prevents buttons from being drawn on peer widgets as scrolling occurs. */
int parent_width = Tk_Width(Tk_Parent(tkwin));
int widget_width = Tk_Width(tkwin);